qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH 3/3] qapi/parser: Remove _JSONObject


From: John Snow
Subject: [PATCH 3/3] qapi/parser: Remove _JSONObject
Date: Thu, 20 May 2021 11:17:59 -0400

Use TopLevelExpr where appropriate now (Any function that accepts
exclusively a Top Level Expression), and replace any other remaining
user with a generic Dict[str, object].

Signed-off-by: John Snow <jsnow@redhat.com>
---
 scripts/qapi/expr.py | 43 ++++++++++++++++++-------------------------
 1 file changed, 18 insertions(+), 25 deletions(-)

diff --git a/scripts/qapi/expr.py b/scripts/qapi/expr.py
index 6d89343897c..005fbf3a7d8 100644
--- a/scripts/qapi/expr.py
+++ b/scripts/qapi/expr.py
@@ -44,18 +44,10 @@
 
 from .common import c_name
 from .error import QAPISemError
-from .parser import ParsedExpression
+from .parser import ParsedExpression, TopLevelExpr
 from .source import QAPISourceInfo
 
 
-# Deserialized JSON objects as returned by the parser.
-# The values of this mapping are not necessary to exhaustively type
-# here (and also not practical as long as mypy lacks recursive
-# types), because the purpose of this module is to interrogate that
-# type.
-_JSONObject = Dict[str, object]
-
-
 # See check_name_str(), below.
 valid_name = re.compile(r'(__[a-z0-9.-]+_)?'
                         r'(x-)?'
@@ -192,7 +184,7 @@ def check_defn_name_str(name: str, info: QAPISourceInfo, 
meta: str) -> None:
                 info, "%s name should not end in '%s'" % (meta, name[-4:]))
 
 
-def check_keys(value: _JSONObject,
+def check_keys(value: Dict[str, object],
                info: QAPISourceInfo,
                source: str,
                required: Collection[str],
@@ -229,11 +221,11 @@ def pprint(elems: Iterable[str]) -> str:
                pprint(unknown), pprint(allowed)))
 
 
-def check_flags(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_flags(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Ensure flag members (if present) have valid values.
 
-    :param expr: The expression to validate.
+    :param expr: The `TopLevelExpr` to validate.
     :param info: QAPI schema source file information.
 
     :raise QAPISemError:
@@ -257,7 +249,8 @@ def check_flags(expr: _JSONObject, info: QAPISourceInfo) -> 
None:
                                  "are incompatible")
 
 
-def check_if(expr: _JSONObject, info: QAPISourceInfo, source: str) -> None:
+def check_if(expr: Dict[str, object], info: QAPISourceInfo,
+             source: str) -> None:
     """
     Normalize and validate the ``if`` member of an object.
 
@@ -430,9 +423,9 @@ def check_features(features: Optional[object],
         check_if(feat, info, source)
 
 
-def check_enum(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_enum(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Normalize and validate this expression as an ``enum`` definition.
 
     :param expr: The expression to validate.
     :param info: QAPI schema source file information.
@@ -468,9 +461,9 @@ def check_enum(expr: _JSONObject, info: QAPISourceInfo) -> 
None:
         check_if(member, info, source)
 
 
-def check_struct(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_struct(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Normalize and validate this expression as a ``struct`` definition.
 
     :param expr: The expression to validate.
     :param info: QAPI schema source file information.
@@ -485,9 +478,9 @@ def check_struct(expr: _JSONObject, info: QAPISourceInfo) 
-> None:
     check_type(expr.get('base'), info, "'base'")
 
 
-def check_union(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_union(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Normalize and validate this expression as a ``union`` definition.
 
     :param expr: The expression to validate.
     :param info: QAPI schema source file information.
@@ -522,9 +515,9 @@ def check_union(expr: _JSONObject, info: QAPISourceInfo) -> 
None:
         check_type(value['type'], info, source, allow_array=not base)
 
 
-def check_alternate(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_alternate(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Normalize and validate this expression as an ``alternate`` definition.
 
     :param expr: The expression to validate.
     :param info: QAPI schema source file information.
@@ -548,9 +541,9 @@ def check_alternate(expr: _JSONObject, info: 
QAPISourceInfo) -> None:
         check_type(value['type'], info, source)
 
 
-def check_command(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_command(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Normalize and validate this expression as a ``command`` definition.
 
     :param expr: The expression to validate.
     :param info: QAPI schema source file information.
@@ -568,9 +561,9 @@ def check_command(expr: _JSONObject, info: QAPISourceInfo) 
-> None:
     check_type(rets, info, "'returns'", allow_array=True)
 
 
-def check_event(expr: _JSONObject, info: QAPISourceInfo) -> None:
+def check_event(expr: TopLevelExpr, info: QAPISourceInfo) -> None:
     """
     Normalize and validate this expression as an ``event`` definition.
 
     :param expr: The expression to validate.
     :param info: QAPI schema source file information.
@@ -430,9 +423,9 @@ def check_features(features: Optional[object],
     """
-    Normalize and validate this expression as an ``enum`` definition.
+    Normalize and validate this `TopLevelExpr` as an ``enum`` definition.
 
     :param expr: The expression to validate.
@@ -468,9 +461,9 @@ def check_enum(expr: _JSONObject, info: QAPISourceInfo) -> 
     """
-    Normalize and validate this expression as a ``struct`` definition.
+    Normalize and validate this `TopLevelExpr` as a ``struct`` definition.
 
     :param expr: The expression to validate.
@@ -485,9 +478,9 @@ def check_struct(expr: _JSONObject, info: QAPISourceInfo) 
     """
-    Normalize and validate this expression as a ``union`` definition.
+    Normalize and validate this `TopLevelExpr` as a ``union`` definition.
 
     :param expr: The expression to validate.
@@ -522,9 +515,9 @@ def check_union(expr: _JSONObject, info: QAPISourceInfo) -> 
     """
-    Normalize and validate this expression as an ``alternate`` definition.
+    Normalize and validate this `TopLevelExpr` as an ``alternate`` definition.
 
     :param expr: The expression to validate.
@@ -548,9 +541,9 @@ def check_alternate(expr: _JSONObject, info: 
     """
-    Normalize and validate this expression as a ``command`` definition.
+    Normalize and validate this `TopLevelExpr` as a ``command`` definition.
 
     :param expr: The expression to validate.
@@ -568,9 +561,9 @@ def check_command(expr: _JSONObject, info: QAPISourceInfo) 
     """
-    Normalize and validate this expression as an ``event`` definition.
+    Normalize and validate this `TopLevelExpr` as an ``event`` definition.
 
     :param expr: The expression to validate.
-- 
2.30.2




reply via email to

[Prev in Thread] Current Thread [Next in Thread]